Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(154)

Unified Diff: content/public/browser/resource_dispatcher_host_delegate.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: use PreviewsState everywhere Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/resource_dispatcher_host_delegate.h
diff --git a/content/public/browser/resource_dispatcher_host_delegate.h b/content/public/browser/resource_dispatcher_host_delegate.h
index 0e5a348e4037cf8a1a8408c25e56ce6922c789b5..c5f12f7c833d9291db129a117704f1636ee5cb67 100644
--- a/content/public/browser/resource_dispatcher_host_delegate.h
+++ b/content/public/browser/resource_dispatcher_host_delegate.h
@@ -12,6 +12,7 @@
#include "base/time/time.h"
#include "content/common/content_export.h"
#include "content/public/browser/resource_request_info.h"
+#include "content/public/common/previews_state.h"
#include "content/public/common/resource_type.h"
#include "ui/base/page_transition_types.h"
@@ -121,10 +122,12 @@ class CONTENT_EXPORT ResourceDispatcherHostDelegate {
// TODO(maksims): Remove this once all the callers are modified.
virtual void RequestComplete(net::URLRequest* url_request);
- // Asks the embedder if Lo-Fi mode should be enabled for the given request. It
- // is only called for requests with an unspecified Lo-Fi value.
- virtual bool ShouldEnableLoFiMode(const net::URLRequest& url_request,
- content::ResourceContext* resource_context);
+ // Asks the embedder for the PreviewsState which says which previews should
+ // be enabled for the given request. It is only called for requests with an
+ // unspecified Previews state.
+ virtual PreviewsState GetPreviewsState(
+ const net::URLRequest& url_request,
+ content::ResourceContext* resource_context);
// Asks the embedder for NavigationData related to this request. It is only
// called for navigation requests.

Powered by Google App Engine
This is Rietveld 408576698